@@ -10,27 +10,28 @@
 # '''
 
 
-#' @title Estimation of a Drifting semi-Markov chain
+#' @title Estimation of a drifting semi-Markov chain
 #' @aliases dsmm_fit dsmm_fit_nonparametric dsmm_fit_parametric
-#' @description Estimation of a Drifting semi-Markov chain,
+#' @description Estimation of a drifting semi-Markov chain,
 #' given one sequence of states. This estimation can be parametric
 #' or non-parametric and is available for
-#' the three types of Drifting semi-Markov models.
+#' the three types of drifting semi-Markov models.
 #'
-#' @param sequence Character vector that represents a sequence of states in
-#'     \eqn{E}. States must be characters with length \eqn{\geq 1}.
-#' @param states Character vector that represents the state space
-#'     \eqn{E}, with length equal to \eqn{s = |E|}.
+#' @param sequence Character vector that represents a sequence of states
+#'     from the state space \eqn{E}.
 #' @param degree Positive integer that represents the polynomial degree
-#'     \eqn{d} for the Drifting semi-Markov model.
+#'     \eqn{d} for the drifting semi-Markov model.
 #' @param f_is_drifting Logical. Specifies if \eqn{f} is drifting or not.
 #' @param p_is_drifting Logical. Specifies if \eqn{p} is drifting or not.
+#' @param states Character vector that represents the state space
+#'     \eqn{E}, with length equal to \eqn{s = |E|}. Default value is set
+#'     equal to the sorted, unique states present in the given sequence.
 #' @param initial_dist Optional. Character that represents the method to
 #'     estimate the initial distribution.
 #'     \itemize{
 #'     \item
 #'           \code{"unif"} : The initial distribution of each state is
-#'           equal to \eqn{1/s}. (\strong{Default value}).
+#'           equal to \eqn{1/s} (default value).
 #'     \item
 #'           \code{"freq"} : The initial distribution of each state is
 #'           equal to the frequency that it has in the sequence.
@@ -40,7 +41,7 @@
 #'     \itemize{
 #'     \item
 #'         \code{"nonparametric"} : The estimation will be
-#'         non-parametric. (\strong{Default value}).
+#'         non-parametric (default value).
 #'     \item
 #'         \code{"parametric"} : The estimation will be
 #'         parametric.
@@ -48,7 +49,7 @@
 #' @param f_dist Optional. It can be defined in two ways:
 #'     \itemize{
 #'     \item If \code{estimation = "nonparametric"}, it is
-#'           equal to \code{NULL}. (\strong{Default value}).
+#'           equal to \code{NULL} (default value).
 #'     \item If \code{estimation = "parametric"}, it is a
 #'         character array that specifies the distributions of the sojourn
 #'         times, for every state transition.
@@ -74,7 +75,7 @@
 #    \emph{Currently not supported}. Default value is \code{FALSE}.
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #'
-#' @details This function estimates a Drifting semi-Markov model in the
+#' @details This function estimates a drifting semi-Markov model in the
 #'     parametric and non-parametric case.
 #'     The parametric estimation can be achieved by the following steps:
 #'     \enumerate{
@@ -88,10 +89,10 @@
 #'     A normalization technique is used in order to correct estimation errors
 #'     from small sequences.
 #'     We will use the exponentials \eqn{(1), (2), (3)} to distinguish between
-#'     the Drifting semi-Markov kernel \eqn{\widehat{q}_{\frac{t}{n}}} and the
+#'     the drifting semi-Markov kernel \eqn{\widehat{q}_{\frac{t}{n}}} and the
 #'     semi-Markov kernels \eqn{\widehat{q}_\frac{i}{d}} used in
 #'     Model 1, Model 2, Model 3.
-#'     More about the theory of Drifting semi-Markov models in \link{dsmmR}.
+#'     More about the theory of drifting semi-Markov models in \link{dsmmR}.
 #'
 #' \strong{Non-parametric Estimation}
 #'
@@ -100,9 +101,9 @@
 #' When the transition matrix \eqn{p} of the embedded Markov chain
 #' \eqn{(J_{t})_{t\in \{0,\dots,n\}}} and
 #' the conditional sojourn time distribution \eqn{f} are both drifting,
-#' the Drifting semi-Markov kernel can be estimated as:
+#' the drifting semi-Markov kernel can be estimated as:
 #' \deqn{\widehat{q}_{\frac{t}{n}}^{\ (1)}(u,v,l) =
-#'       \sum_{i = 0}^{d}A_{i}(t)\widehat{q}_{\frac{i}{d}}^{\ (1)}(u,v,l),}
+#'       \sum_{i = 0}^{d}A_{i}(t)\ \widehat{q}_{\frac{i}{d}}^{\ (1)}(u,v,l),}
 #' \eqn{\forall t \in \{0,\dots,n\}, \forall u,v\in E,
 #' \forall l \in \{1,\dots, k_{max} \} }, where \eqn{k_{max}} is the maximum
 #' sojourn time that was observed in the sequence and
@@ -194,10 +195,10 @@
 #' \strong{\emph{Model 2}}
 #'
 #' In this case, \eqn{p} is drifting and \eqn{f} is not drifting. Therefore,
-#' the estimated Drifting semi-Markov kernel will be given by:
+#' the estimated drifting semi-Markov kernel will be given by:
 #'
 #' \deqn{\widehat{q}_{\frac{t}{n}}^{\ (2)}(u,v,l) =
-#' \sum_{i=0}^{d} A_{i}(t) \widehat{q}_{\frac{i}{d}}^{\ (2)}(u,v,l),}
+#' \sum_{i=0}^{d} A_{i}(t)\ \widehat{q}_{\frac{i}{d}}^{\ (2)}(u,v,l),}
 #'
 #' \eqn{\forall t \in \{0,\dots,n\}, \forall u,v\in E,
 #' \forall l\in \{1,\dots, k_{max} \}}, where \eqn{k_{max}} is the maximum
@@ -233,9 +234,9 @@
 #' \strong{\emph{Model 3}}
 #'
 #' In this case, \eqn{f} is drifting and \eqn{p} is not drifting. Therefore,
-#' the estimated Drifting semi-Markov kernel will be given by:
+#' the estimated drifting semi-Markov kernel will be given by:
 #' \deqn{\widehat{q}_{\frac{t}{n}}^{\ (3)}(u,v,l) =
-#' \sum_{i=0}^{d} A_{i}(t) \widehat{q}_{\frac{i}{d}}^{\ (3)}(u,v,l),}
+#' \sum_{i=0}^{d} A_{i}(t)\ \widehat{q}_{\frac{i}{d}}^{\ (3)}(u,v,l),}
 #' \eqn{\forall t \in \{0,\dots,n\}, \forall u,v\in E,
 #' \forall l\in \{1,\dots, k_{max} \}}, where \eqn{k_{max}} is the maximum
 #' sojourn time that was observed in the sequence and
@@ -282,8 +283,8 @@
 #'         in previously in \eqn{1}.
 #' }
 #'
-#' The available distributions for the modeling of the conditional sojourn
-#' times of the Drifting semi-Markov model, defined from
+#' The available distributions for the modelling of the conditional sojourn
+#' times of the drifting semi-Markov model, defined from
 #' the argument \code{f_dist}, have their parameters estimated through the
 #' following formulas:
 #' \itemize{
@@ -386,7 +387,7 @@
 #'   time, which is the maximum value in \code{soj_times}, excluding the last
 #'   state.
 #' \item \code{model_size} : Positive integer that contains the size of the
-#'   Drifting semi-Markov model \eqn{n}, which is equal to the length of the
+#'   drifting semi-Markov model \eqn{n}, which is equal to the length of the
 #'   embedded Markov chain \eqn{(J_{t})_{t\in \{0,\dots,n\}}},
 #'   minus the last state.
 #'   It has a value of \code{length(seq) - 1}, for \code{seq} as defined above.
@@ -419,14 +420,14 @@
 #' }
 #'
 #' @seealso
-#' For the theoretical background of Drifting semi-Markov models: \link{dsmmR}.
+#' For the theoretical background of drifting semi-Markov models: \link{dsmmR}.
 #'
 #' For sequence simulation: \link{simulate.dsmm} and \link{create_sequence}.
 #'
-#' For Drifting semi-Markov model specification:
+#' For drifting semi-Markov model specification:
 #' \link{parametric_dsmm}, \link{nonparametric_dsmm}
 #'
-#' For the retrieval of the Drifting semi-Markov kernel:
+#' For the retrieval of the drifting semi-Markov kernel:
 #' \link{get_kernel}.
 #'
 #' @references
@@ -439,7 +440,7 @@
 #' Molecular Biology 7 (1).
 #'
 #' Barbu V. S., Vergne, N. (2019). Reliability and survival analysis for
-#' drifting Markov models: modeling and estimation.
+#' Drifting Markov models: modelling and estimation.
 #' Methodology and Computing in Applied Probability, 21(4), 1407-1429.
 #'
 #' T. Nakagawa and S. Osaki. (1975). The discrete Weibull distribution.
@@ -461,15 +462,17 @@
 #' # Fitting a random sequence under distributions of unknown shape.
 #' # ===========================================================================
 #'
+#'
+#'
 #' # ---------------------------------------------------------------------------
 #' # Both p and f are drifting - Model 1.
 #' # ---------------------------------------------------------------------------
 #'
 #' obj_model_1 <- fit_dsmm(sequence = sequence,
-#'                         states = states,
 #'                         degree = degree,
 #'                         f_is_drifting = TRUE,
 #'                         p_is_drifting = TRUE,
+#'                         states = states,
 #'                         initial_dist = "freq",
 #'                         estimation = "nonparametric", # default value
 #'                         f_dist = NULL # default value
@@ -490,37 +493,43 @@
 #'            "Dimension of f_drift: (s, s, k_max, d + 1) = (",
 #'            paste(dim(f_drift), collapse = ", "), ").\n"))
 #'
+#'
 #' # ---------------------------------------------------------------------------
 #' # Fitting the sequence when p is drifting and f is not drifting - Model 2.
 #' # ---------------------------------------------------------------------------
 #'
+#'
 #' obj_model_2 <- fit_dsmm(sequence = sequence,
-#'                         states = states,
 #'                         degree = degree,
-#'                         initial_dist = "unif",
 #'                         f_is_drifting = FALSE,
 #'                         p_is_drifting = TRUE)
 #'
+#'
 #' cat(paste0("We fitted a sequence with ", obj_model_2$Model, ".\n"))
 #'
+#'
 #' # Get the drifting p and non-drifting f arrays.
 #' p_drift_2 <- obj_model_2$dist$p_drift
 #' f_notdrift <- obj_model_2$dist$f_notdrift
 #'
+#'
 #' all.equal.numeric(p_drift, p_drift_2) # p is the same as in Model 1.
 #'
+#'
 #' cat(paste0("Dimension of f_notdrift: (s, s, k_max) = (",
 #'            paste(dim(f_notdrift), collapse = ", "), ").\n"))
 #'
+#'
+#'
 #' # ---------------------------------------------------------------------------
 #' # Fitting the sequence when f is drifting and p is not drifting - Model 3.
 #' # ---------------------------------------------------------------------------
 #'
 #' obj_model_3 <- fit_dsmm(sequence = sequence,
-#'                         states = states,
 #'                         degree = degree,
 #'                         f_is_drifting = TRUE,
 #'                         p_is_drifting = FALSE)
+#'
 #' cat(paste0("We fitted a sequence with ", obj_model_3$Model, ".\n"))
 #' # Get the drifting f and non-drifting p arrays.
 #' p_notdrift <- obj_model_3$dist$p_notdrift
@@ -557,10 +566,10 @@
 #' # ---------------------------------------------------------------------------
 #'
 #' obj_fit_parametric <- fit_dsmm(sequence = sequence,
-#'                                states = states,
 #'                                degree = degree,
 #'                                f_is_drifting = TRUE,
 #'                                p_is_drifting = TRUE,
+#'                                states = states,
 #'                                initial_dist = 'unif',
 #'                                estimation = 'parametric',
 #'                                f_dist = f_dist)
@@ -590,13 +599,13 @@
 #' # ---------------------------------------------------------------------------
 #'
 #' obj_fit_parametric_2 <- fit_dsmm(sequence = sequence,
-#'                                  states = states,
 #'                                  degree = degree,
 #'                                  f_is_drifting = FALSE,
 #'                                  p_is_drifting = TRUE,
 #'                                  initial_dist = 'unif',
 #'                                  estimation = 'parametric',
 #'                                  f_dist = f_dist_1)
+#'
 #' cat("The class of `obj_fit_parametric_2` is : (",
 #'     paste0(class(obj_fit_parametric_2), collapse = ', '), ").\n")
 #' # Estimated parameters.
@@ -606,11 +615,10 @@
 #'                    ', beta = ', round(f_params_2["c", "t", 2], 3))
 #'
 #' cat("Not-drifting parameters for passing from ",
-#'     "`u` = 'c' to `v` = 't' \n under a discrete Weibull distribution is:\n",
+#'     "`u` = 'c' to `v` = 't' \n under a discrete Weibull distribution are:\n",
 #'     paste("f :", params_2))
 #'
 #'
-#'
 #' # ===========================================================================
 #' # Some methods for the `dsmm_fit_nonparametric` and
 #' #  `dsmm_fit_parametric` objects.
@@ -624,22 +632,25 @@
 #' kernel_drift_parametric <- get_kernel(obj_fit_parametric, klim = 10)
 #' str(kernel_drift_parametric)
 #'
-fit_dsmm <- function(sequence, states, degree,
-                     f_is_drifting, p_is_drifting,
+fit_dsmm <- function(sequence,
+                     degree,
+                     f_is_drifting,
+                     p_is_drifting,
+                     states = NULL,
                      initial_dist = "unif",
                      estimation = "nonparametric",
                      f_dist = NULL
                      # numerical_est = FALSE # placeholder for a future version.
-                     ) {
+) {
     # Sequence
     if (missing(sequence)) {
         stop("\nPlease provide the `sequence` character ",
              "vector in order to fit the model.")
     }
     # State Space
-    if (missing(states)) {
-        stop("\nPlease provide a character vector for the",
-    "`states` of the State Space.")
+    if (is.null(states) && valid_sequence(sequence)) {
+        # Default value
+        states <- sort(unique(sequence))
     }
     # Degree
     if (missing(degree)) {
@@ -833,36 +844,36 @@ fit_dsmm <- function(sequence, states, degree,
                     f_il <- f_ijl[,j,]
                     dist_i <- dist_ij[,j]
                     sapply(1:s, function(i) {
-                            if (i == j) {
-                                return(c(NA, NA)) # Skip diagonal values.
-                            }
-                            f_l <- f_il[i,]
-                            par_dist <- dist_i[i]
-                            sum_fl <- sum(f_l)
-                            if (is.na(par_dist)) {
-                                if (sum_fl != 0) {
-                                    stop("For the states u = ", i, ", v = ", j,
-                                         " and ", names_i_d(degree, 'f')[d],
-                                         " `f_dist` was defined to be NA, ",
-                                         "however we do have occurences in ",
-                                         "the sequence, corresponding to ",
-                                         "these states. Therefore, a ",
-                                         "distribution should be chosen.")
-                                }
-                                return(c(NA, NA))
-                            } else if (sum_fl == 0) {
+                        if (i == j) {
+                            return(c(NA, NA)) # Skip diagonal values.
+                        }
+                        f_l <- f_il[i,]
+                        par_dist <- dist_i[i]
+                        sum_fl <- sum(f_l)
+                        if (is.na(par_dist)) {
+                            if (sum_fl != 0) {
                                 stop("For the states u = ", i, ", v = ", j,
                                      " and ", names_i_d(degree, 'f')[d],
-                                     " we have no occurences in the sequence.",
-                                     " Therefore, `f_dist` has to be NA.")
+                                     " `f_dist` was defined to be NA, ",
+                                     "however we do have occurences in ",
+                                     "the sequence, corresponding to ",
+                                     "these states. Therefore, a ",
+                                     "distribution should be chosen.")
                             }
-                            suppressWarnings( # because NA is being generated.
-                                parametric_estimation(
-                                    lprobs = f_l, dist = par_dist, kmax = k_max,
-                                    i = i, j = j, d = d, degree = degree,
-                                    states = states
-                                )
+                            return(c(NA, NA))
+                        } else if (sum_fl == 0) {
+                            stop("For the states u = ", i, ", v = ", j,
+                                 " and ", names_i_d(degree, 'f')[d],
+                                 " we have no occurences in the sequence.",
+                                 " Therefore, `f_dist` has to be NA.")
+                        }
+                        suppressWarnings( # because NA is being generated.
+                            parametric_estimation(
+                                lprobs = f_l, dist = par_dist, kmax = k_max,
+                                i = i, j = j, d = d, degree = degree,
+                                states = states
                             )
+                        )
                     })
                 })
             })
